@@ -1,5 +1,7 @@
-from typing import List
+from collections import defaultdict
+from typing import Dict, List
 
+from sacrerouge.data import Metrics, MetricsDict
 from sacrerouge.data.types import ReferenceType, SummaryType
 from sacrerouge.io import JsonlReader
 
@@ -23,3 +25,11 @@ def load_references(file_path: str) -> List[ReferenceType]:
         elif 'references' in data:
             fields.append([reference['text'] for reference in data['references']])
     return fields
+
+
+def load_metrics_dicts(file_path: str) -> Dict[str, Dict[str, MetricsDict]]:
+    metrics_dicts = defaultdict(dict)
+    with JsonlReader(file_path, Metrics) as f:
+        for instance in f:
+            metrics_dicts[instance.instance_id][instance.summarizer_id] = instance.metrics
+    return metrics_dicts
\ No newline at end of file
