@@ -1,6 +1,7 @@
 import argparse
 import logging
 import os
+import sys
 from collections import defaultdict
 from overrides import overrides
 from subprocess import Popen, PIPE
@@ -236,7 +237,19 @@ class RougeSetupSubcommand(Subcommand):
     @overrides
     def run(self, args):
         print(f'Downloading ROUGE-1.5.5')
-        download_file_from_google_drive('1y0rDnTplQ83b2PQu_TgezbFpGOthP0gG', f'{DATA_ROOT}/metrics/ROUGE-1.5.5.zip')
+
+        # I believe the ROUGE data files are platform-dependent. We verify it runs later, but in case it is, we have
+        # to download the data files for the platform.
+        # https://stackoverflow.com/questions/8220108/how-do-i-check-the-operating-system-in-python
+        if sys.platform in ['linux', 'linux2']:
+            file_id = '1K4J2wHGjAyr3LoSgaQuWZ_YyjtUGf26m'
+        elif sys.platform == 'darwin':
+            file_id = '1y0rDnTplQ83b2PQu_TgezbFpGOthP0gG'
+        else:
+            # No idea -- default to Linux
+            file_id = '1K4J2wHGjAyr3LoSgaQuWZ_YyjtUGf26m'
+
+        download_file_from_google_drive(file_id, f'{DATA_ROOT}/metrics/ROUGE-1.5.5.zip')
 
         commands = [
             f'cd {DATA_ROOT}/metrics',
@@ -247,7 +260,28 @@ class RougeSetupSubcommand(Subcommand):
 
         process = Popen(command, shell=True)
         process.communicate()
-        if process.returncode == 0:
-            print('ROUGE setup success')
-        else:
+        if process.returncode != 0:
             print('ROUGE setup failure')
+
+        # ROUGE has data files which may not successfully load. Therefore, if it fails to run on a simple example,
+        # the user needs to run some perl code within the ROUGE directory to correct the data file
+        try:
+            summary = 'Dan walked to the bakery this morning.'
+            reference = 'Dan went to buy scones earlier this morning.'
+            rouge = Rouge()
+            rouge.score(summary, [reference])
+            print('ROUGE setup success')
+        except IndexError:
+            print('ROUGE setup failure')
+            print('It is very likely that you need to rebuild the ROUGE database file. See '
+                  'https://github.com/danieldeutsch/sacrerouge/blob/master/doc/metrics/rouge.md for '
+                  'instructions on how to rebuild the necessary file. Afterward, this example '
+                  'should run without failing:')
+            print()
+            print('>>> from sacrerouge.metrics import Rouge')
+            print('>>> ')
+            print('>>> summary = "Dan walked to the bakery this morning."')
+            print('>>> reference = "Dan went to buy scones earlier this morning."')
+            print('>>> ')
+            print('>>> rouge = Rouge()')
+            print('>>> rouge.score(summary, [reference])')
